pub enum TrapReason {
Show 15 variants
Unreachable,
Host,
DivideByZero,
InvalidTableIndex,
InvalidTableFunctionType,
UninitializedTableElement,
GlobalGetFailed,
GlobalSetFailed,
OutOfMemory,
MemoryRefNotUnique,
MemoryOutOfBounds,
StackOverflow,
UnrepresentableResult,
IntegerOverflow,
BadConversionToInteger,
}Variants
Unreachable
Triggered by unreachable instruction
Host
A host function has noted an unrecoverable failure
DivideByZero
Integer or floating point division by zero
InvalidTableIndex
An indirect call tried to map to a table function out of range
InvalidTableFunctionType
The function type in an indirect call does not match the function pointer’s type
UninitializedTableElement
An indirect call tried to map to a table function out of range
GlobalGetFailed
An imported global could not be read
GlobalSetFailed
An imported global could not be set
OutOfMemory
A memory operation is out of bounds
MemoryRefNotUnique
memory.grow failed because a host function has taken ownership of a memory
MemoryOutOfBounds
A memory operation is out of bounds
StackOverflow
Ran out of stack space
UnrepresentableResult
Attempting to convert Inf to integer
IntegerOverflow
Signed division causes integer overflow
BadConversionToInteger
Attempting to convert NaN to integer